@@ -7,7 +7,7 @@ use Carp;
 use Template::Reverse::Part;
 use Algorithm::Diff qw(sdiff);
 use Scalar::Util qw(blessed);
-our $VERSION = '0.120'; # VERSION
+our $VERSION = '0.121'; # VERSION
 
 
 has 'sidelen' => (
@@ -15,6 +15,7 @@ has 'sidelen' => (
     default => 10
 );
 
+
 my $_WILDCARD = bless [], 'WILDCARD';
 sub WILDCARD{return $_WILDCARD};
 sub _isWILDCARD{
@@ -114,7 +115,7 @@ Template::Reverse - A template generator getting different parts between pair of
 
 =head1 VERSION
 
-version 0.120
+version 0.121
 
 =head1 SYNOPSIS
 
@@ -173,15 +174,16 @@ If you set it as 3, you get max 3 length pre-text and post-text array each part.
 
 This is needed for more faster performance.
 
-=head3 detect($arr_of_text1, $arr_of_text2)
+=head3 WILDCARD()
 
-=head3 detect($tokens1, $tokens2)
+WILDCARD() returns a blessed array reference as 'WILDCARD' to means WILDCARD token.
+This is used by _diff() and _detect().
 
-Get an array-ref of L<Template::Reverse::Part> from two array-refs.
+=head3 detect($arr_ref1, $arr_ref2)
+
+Get an array-ref of L<Template::Reverse::Part> from two array-refs which contains text or object implements as_string() method.
 A L<Template::Reverse::Part> class means an one changable token.
 
-The token is L<Parse::Token::Lite::Token>.
-
 It returns like below.
 
     $rev->detect([qw(A b C)], [qw(A d C)]);
@@ -218,11 +220,19 @@ It returns like below.
     #           Part #1               Part #2
     #
 
+    # You can get same result for object arrays.
+    my $objs1 = [$obj1, $obj2, $obj3];
+    my $objs2 = [$obj1, $obj3];
+    #
+    # [ { [ $obj1 ], [ $obj3 ] } ]
+    #   : :.......:  :.......: :
+    #   :    pre       post    :
+    #   :......................:
+    #           Part #1
+
 Returned arrayRef is list of changable parts.
 
-    1. At first, $text1 and $text2 is normalized by Spacers.
-    2. 'pre texts' and 'post texts' are splited by Splitter. In this case, by Whitespace.
-    3. You can get a changing value, just finding 'pre' and 'post' in a normalized text.
+    You can get a changed token if you find just 'pre' and 'post' sequences on any other token array.
 
 =head1 SEE ALSO
 
